# memosa (beta)

memoization with minimal modifications (decorators, contexts)

saves memoized results between runs for faster development

useful for rapid prototyping

supports Python 3.6+

check out the [examples](https://github.com/Waffles32/memosa/tree/master/examples)
